StateBuilder<S> class
StateBuilder handles building a widget in response to new states.
StateBuilder is analogous to StreamBuilder but has simplified API to
reduce the amount of boilerplate code needed as well as state-specific
performance improvements.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- StateBuilder
Constructors
-
StateBuilder({Key? key, required StateNotifier<
S> notifier, required StateHandlerFunction<S> builder, StateListenerFunction<S> ? listener, StateConditionFunction<S> ? buildWhen, StateConditionFunction<S> ? listenWhen}) -
const
Properties
-
builder
→ StateHandlerFunction<
S> -
Called when the StateNotifier notifies about a change and
the if the
statepass thebuilderWhenfilter (if set).final -
buildWhen
→ StateConditionFunction<
S> ? -
Condition to determine if the builder should be called or not.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
listener
→ StateListenerFunction<
S> ? -
Called when the StateNotifier notifies about a change and
the if the
statepass thelistenWhenfilter (if set).final -
listenWhen
→ StateConditionFunction<
S> ? -
Condition to determine if the listener should be called or not.
final
-
notifier
→ StateNotifier<
S> -
The StateNotifier supplied to the constructor.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StateBuilder> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited