Takes a StateNotifier and invokes the listener in response to state changes.
It should be used for functionality that needs to occur only in response to
a state change such as navigation, showing a SnackBar, showing
a Dialog, etc...
The listener is guaranteed to only be called once for each state change
unlike the builder in StateBuilder.
Specialized StateNotifier for List data types.
With this StateNotifier type you can set a filter and work with
only a subset (filtered items) of the main List.
Specialized StateNotifier which handles initializing the StateNotifier
state based on the persisted state. This allows state to be persisted
across application restarts.
StateBuilder handles building a widget in response to new states.
StateBuilder is analogous to StreamBuilder but has simplified API to
reduce the amount of boilerplate code needed as well as state-specific
performance improvements.
Takes a StateNotifier and invokes the listener in response to state changes.
It should be used for functionality that needs to occur only in response to
a state change such as navigation, showing a SnackBar, showing
a Dialog, etc...
The listener is guaranteed to only be called once for each state change
unlike the builder in StateBuilder.
Takes a StateNotifier and invokes the listener in response to state changes.
It should be used for functionality that needs to occur only in response to
a state change such as navigation, showing a SnackBar, showing
a Dialog, etc...
The listener is guaranteed to only be called once for each state change
unlike the builder in StateBuilder.
Checker for the buildWhen and listenWhen functions which takes
the previous state and the current state and returns true if
they are not equals (aka different).
Signature for the buildWhen and listenWhen functions which takes
the previous state and the current state and is responsible
for returning a bool which determines whether to the new state
should be emitted to the expected widget.
Signature for the buildWhen and listenWhen functions which takes
the previous state and the current state and is responsible
for returning a bool which determines whether to the new state
should be emitted to the expected widget.
Signature for the buildWhen and listenWhen functions which takes
the previous state and the current state and is responsible
for returning a bool which determines whether to the new state
should be emitted to the expected widget.