StateObserver class abstract
A StateObserver which will be used to notify about state changes. The observer notify each state changing on events:
- onCreated: when a StateNotifier is created.
- onStateChanged: when a StateNotifier state is changed.
- onStateRecovered: when a StateNotifier state is recovered.
- onDisposed: when a StateNotifier is disposed.
Constructors
- StateObserver()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCreated(
StateNotifier stateNotifier, dynamic initialState) → void -
onDisposed(
StateNotifier stateNotifier) → void -
onStateChanged(
StateNotifier stateNotifier, dynamic previousState, dynamic newState) → void -
onStateRecovered(
StateNotifier stateNotifier, dynamic state) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited